..
.. Copyright 2018-2021 Elyra Authors
..
.. Licensed under the Apache License, Version 2.0 (the "License");
.. you may not use this file except in compliance with the License.
.. You may obtain a copy of the License at
..
.. http://www.apache.org/licenses/LICENSE-2.0
..
.. Unless required by applicable law or agreed to in writing, software
.. distributed under the License is distributed on an "AS IS" BASIS,
.. WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
.. See the License for the specific language governing permissions and
.. limitations under the License.
..


.. Elyra documentation master file, created by
   sphinx-quickstart on Wed Apr 29 21:41:11 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Elyra Documentation
=================================

Elyra is a set of AI-centric extensions to JupyterLab Notebooks.

.. toctree::
   :maxdepth: 1
   :caption: Getting Started

   getting_started/overview
   getting_started/installation
   getting_started/starting
   getting_started/tutorials
   getting_started/getting-help
   getting_started/changelog

.. toctree::
   :maxdepth: 1
   :caption: User Guide

   user_guide/runtime-conf
   user_guide/runtime-image-conf
   user_guide/pipelines
   user_guide/enhanced-python-support
   user_guide/code-snippets

.. toctree::
   :maxdepth: 1
   :caption: Recipes

   recipes/deploying-elyra-in-a-jupyterhub-environment.md
   recipes/deploying-kubeflow-locally-for-dev.md
   recipes/deploying-elyra-with-opendatahub.md
   recipes/creating-a-custom-runtime-image.md
   recipes/visualizing-output-in-the-kfp-ui.md
   recipes/configure-airflow-as-a-runtime.md
   
.. toctree::
   :maxdepth: 1
   :caption: Developer Guide

   developer_guide/development-workflow
   developer_guide/contributing
   developer_guide/logging
   developer_guide/metadata
   developer_guide/pipelines
   developer_guide/trackers
   developer_guide/testing
   developer_guide/documentation
   developer_guide/release
